﻿using System.Linq;
using JMS.DVB;


namespace SampleArgusTVRecordingService
{
    /// <summary>
    /// Ein einzelnes Aufzeichnungsgerät.
    /// </summary>
    public class RecordingDevice
    {
        /// <summary>
        /// Der Name des Gerätes.
        /// </summary>
        public string Name { get; private set; }

        /// <summary>
        /// Die Anzahl laufender Aufzeichnungen.
        /// </summary>
        private int m_recordingCount;

        /// <summary>
        /// Die aktuelle Quellgruppe.
        /// </summary>
        private SourceSelection m_group;

        /// <summary>
        /// Meldet das DVB.NET Geräteprofil.
        /// </summary>
        public Profile Profile { get { return ProfileManager.FindProfile( Name ); } }

        /// <summary>
        /// Erstellt eine neue Simulation.
        /// </summary>
        /// <param name="name">Der Name des Gerätes.</param>
        public RecordingDevice( string name )
        {
            // Remember
            Name = name;
        }

        /// <summary>
        /// Beginnt eine neue Aufzeichnung.
        /// </summary>
        /// <param name="possibleSources">Die neuen Quellen.</param>
        /// <returns>Gesetzt, wenn ein Start möglich war.</returns>
        public bool Start( SourceSelection[] possibleSources )
        {
            // Get original counter
            var counter = m_recordingCount++;

            // Check mode
            if (counter == 0)
                m_group = possibleSources[0];
            else if (possibleSources.All( possible => !m_group.CompareTo( possible, true ) ))
                m_recordingCount--;

            // Check result
            return (counter != m_recordingCount);
        }

        /// <summary>
        /// Beendet eine Aufzeichnung.
        /// </summary>
        public void Stop()
        {
            // Just correct
            m_recordingCount--;
        }
    }
}
