﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;


namespace SampleArgusTVRecordingService
{
    /// <summary>
    /// Alle aktuell verfügbaren Geräte.
    /// </summary>
    public class RecordingDevices : IEnumerable<RecordingDevice>
    {
        /// <summary>
        /// Alle unterstützten Geräte.
        /// </summary>
        private readonly Dictionary<string, RecordingDevice> m_devices =
            Properties
                .Settings
                .Default
                .Profiles
                .Split( ':' )
                .ToDictionary( profileName => profileName, profileName => new RecordingDevice( profileName ), StringComparer.InvariantCultureIgnoreCase );

        /// <summary>
        /// Meldet den Vergleichsalgorithmus für Namen.
        /// </summary>
        public IEqualityComparer<string> NameComparer { get { return m_devices.Comparer; } }

        /// <summary>
        /// Meldet ein Gerät mit einem bestimmten Namen.
        /// </summary>
        /// <param name="deviceName">Der Name des gwünschten Gerätes.</param>
        public RecordingDevice this[string deviceName]
        {
            get
            {
                // Load
                RecordingDevice device;
                if (m_devices.TryGetValue( deviceName, out device ))
                    return device;
                else
                    return null;
            }
        }

        /// <summary>
        /// Meldet eine auflistung über alle Geräte.
        /// </summary>
        /// <returns>Die gewünschte Auflistung.</returns>
        public IEnumerator<RecordingDevice> GetEnumerator()
        {
            // Forward
            return m_devices.Values.GetEnumerator();
        }

        /// <summary>
        /// Meldet eine auflistung über alle Geräte.
        /// </summary>
        /// <returns>Die gewünschte Auflistung.</returns>
        IEnumerator IEnumerable.GetEnumerator()
        {
            // Forward
            return GetEnumerator();
        }
    }
}
